
COCOMO
------

A simple wrapper, essentially implementing the details written out
by David A. Wheeler and relying on his SLOCCount binary to do all
the heavy lifting. http://www.dwheeler.com/sloccount/sloccount.html
